@@ -17,16 +17,23 @@
 /* Savable and configurable controls/data */
 
 /* Pause        Shield     Thrust  TurnR      TurnL     Fire     Quit  */
+Controls controls =
 #ifdef FAITHFUL_SPECS
-Controls controls =
-{ SDLK_CAPSLOCK,SDLK_SPACE,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_TAB,SDLK_ESCAPE };
+	{ SDLK_CAPSLOCK,SDLK_SPACE,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_TAB,SDLK_ESCAPE };
 #else
-#ifdef MAEMO
-Controls controls =
-   { SDLK_F8,SDLK_F4,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_RETURN,SDLK_ESCAPE };
+
+#ifdef MAEMO_SDK
+#if MAEMO_SDK==5
+	{ SDLK_p,SDLK_x,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_z,SDLK_q };
+#elif MAEMO_SDK==4
+	{ SDLK_F8,SDLK_F4,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_RETURN,SDLK_ESCAPE };
+#elif MAEMO_SDK==2
+	{ SDLK_F8,SDLK_F4,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_RETURN,SDLK_ESCAPE };
 #else
-Controls controls =
-   { SDLK_PAUSE,SDLK_SPACE,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_TAB,SDLK_ESCAPE };
+#error Unknown or unsupported maemo version given
+#endif
+#else
+	{ SDLK_PAUSE,SDLK_SPACE,SDLK_UP,SDLK_RIGHT,SDLK_LEFT,SDLK_TAB,SDLK_ESCAPE };
 #endif
 #endif
 
@@ -471,12 +478,14 @@ mesg("Movie is %s...\n", gMovie ? "started" : "stopped");
 
 #ifdef MAEMO
 		case SDL_ACTIVEEVENT:
-			if (event->active.gain==0 && event->active.state & SDL_APPINPUTFOCUS) {
+			if (event->active.gain==0 && gFocus==1 && event->active.state & SDL_APPINPUTFOCUS) {
 				gFocus=0;
 			}
 			if (event->active.gain==1 && event->active.state & SDL_APPINPUTFOCUS) {
 				gFocus=1;
 			}
+			if (gFocus==0)
+				SetControl(PAUSE_KEY, 1);
 			printf("Focus: %d\n", gFocus);
 		break;
 #endif
