@@ -12,6 +12,7 @@
 #include "colortable.h"
 #include "fastrand.h"
 
+#include "config.h"
 
 // Global variables set in this file...
 Sound    *sound = NULL;
@@ -780,10 +781,7 @@ int DoInitializations(Uint32 video_flags)
 		error("Fatal: %s\n", screen->Error());
 		return(-1);
 	}
-	/* XXX workaround SDL/Matchbox input handling bug on Fremantle */
-#ifndef MAEMO
 	screen->SetCaption("Maelstrom");
-#endif
 	atexit(CleanUp);		// Need to reset this under X11 DGA
 	SDL_FreeSurface(icon);
 
@@ -802,6 +800,10 @@ int DoInitializations(Uint32 video_flags)
 	gClipRect.h = gBottom-gTop-2*SPRITES_WIDTH+STATUS_HEIGHT;
 	screen->ClipBlit(&gClipRect);
 
+#ifdef MAEMO
+	/* Hide mouse */
+	SDL_ShowCursor(0);
+#endif
 	/* Do the Ambrosia Splash screen */
 	screen->Clear();
 	screen->Update();
